import { ChangeHistoryAction, ElementOrSelector } from '../utils';
import { MorphLink } from './MorphLink';
export interface MorphOptions {
    base: string;
    waitForHeadToLoad: boolean;
    cachePages: boolean;
    trailingSlash: boolean;
    scrollSelector: string;
}
export interface MorphNavigationEntry {
    pathname: string;
}
export interface MorphTransitionEntry extends MorphNavigationEntry {
}
export interface MorphChildrenActionEntry {
    morphElement: HTMLElement;
    pathname: string;
}
export interface MorphPreprocessorEntry extends MorphNavigationEntry {
    resolve: () => void;
    reject: () => void;
}
export type MorphPreprocessor = (entry: MorphPreprocessorEntry) => void;
export type MorphNavigationCallback = (entry: MorphNavigationEntry) => void;
export interface MorphNavigateOptions {
    historyAction?: ChangeHistoryAction;
    centerScroll?: boolean;
    offsetScroll?: number | ElementOrSelector<HTMLElement>;
    revalidate?: boolean;
}
export interface MorphEvents {
    morphStart: CustomEvent<MorphTransitionEntry>;
    morphComplete: CustomEvent<MorphTransitionEntry>;
    morphNewChildrenAdded: CustomEvent<MorphChildrenActionEntry>;
    morphOldChildrenRemoved: CustomEvent<MorphChildrenActionEntry>;
}
export declare class Morph {
    #private;
    preprocessor?: MorphPreprocessor;
    constructor(parameters?: Partial<MorphOptions>);
    get currentPathname(): string;
    get previousPathname(): string | undefined;
    get links(): MorphLink[];
    get scrollElement(): HTMLElement;
    normalizePath(path: string): {
        leaf: string;
        pathname: string;
        parameters: string;
        hash: string;
    };
    prefetch(path: string): Promise<void>;
    navigate(path: string, { historyAction, centerScroll, offsetScroll, revalidate, }?: MorphNavigateOptions): Promise<void>;
    addLink(element: HTMLAnchorElement): void;
    addLinks(elements: Array<HTMLAnchorElement>): void;
    removeLink(element: HTMLAnchorElement): void;
    findLinks(): void;
}
declare global {
    interface DocumentEventMap extends MorphEvents {
    }
}
