export interface StoreState<StoreType> {
    current: StoreType;
    previous: StoreType | undefined;
    initial: StoreType;
}
export type StoreSubscribeCallback<StoreType> = (state: StoreState<StoreType>) => void;
export type StoreEqualityCheckCallback<StoreType> = (currentValue: StoreType, newValue: StoreType) => boolean;
export type StoreMiddleware<T> = (value: T) => T;
export interface StoreOptions<StoreType> {
    name?: string;
    __manager?: any;
    equalityCheck?: StoreEqualityCheckCallback<StoreType>;
    validate?: StoreMiddleware<StoreType>;
    skipSubscribeNotification?: boolean;
    notifyAndClose?: boolean;
    invisible?: boolean;
}
export declare class Store<StoreType = unknown> {
    #private;
    __manager?: any;
    constructor(value: StoreType, options?: StoreOptions<StoreType>);
    get name(): string | undefined;
    get initial(): StoreType;
    get previous(): StoreType | undefined;
    get current(): StoreType;
    set current(value: StoreType);
    get subscribers(): Set<StoreSubscribeCallback<StoreType>>;
    addMiddleware(middleware: StoreMiddleware<StoreType>): void;
    removeMiddleware(middleware: StoreMiddleware<StoreType>): void;
    subscribe(callback: StoreSubscribeCallback<StoreType>): () => void;
    unsubscribe(callback: StoreSubscribeCallback<StoreType>): void;
    reset(): void;
    close(): void;
}
export declare const activeStores: Store<Store<any>[]>;
